@@ -13,8 +13,8 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.
 */
 
 #include "katedocmanager.h"
@@ -28,22 +28,22 @@
 
 #include <kate/view.h>
 
+#include <ktexteditor/encodinginterface.h>
+
 #include <kparts/factory.h>
 
 #include <klocale.h>
 #include <kdebug.h>
 #include <kconfig.h>
-#include <kapplication.h>
 #include <klibloader.h>
 #include <kmdcodec.h>
+#include <kmessagebox.h>
+#include <kencodingfiledialog.h>
+#include <kio/job.h>
 
 #include <qdatetime.h>
 #include <qtextcodec.h>
 #include <qprogressdialog.h>
-#include <kmessagebox.h>
-#include <kencodingfiledialog.h>
-#include <ktexteditor/encodinginterface.h>
-
 
 KateDocManager::KateDocManager (QObject *parent)
  : QObject (parent)
@@ -60,13 +60,16 @@ KateDocManager::KateDocManager (QObject *parent)
   m_dcop = new KateDocManagerDCOPIface (this);
 
   m_metaInfos = new KConfig("metainfos", false, false, "appdata");
-  Kate::Document::registerCommand(KateExternalToolsCommand::self());
 
   createDoc ();
 }
 
 KateDocManager::~KateDocManager ()
 {
+  // save config
+  if (!m_docList.isEmpty())
+    m_docList.at(0)->writeConfig(KateApp::self()->config());
+
   if (m_saveMetaInfos)
   {
     // saving meta-infos when file is saved is not enough, we need to do it once more at the end
@@ -95,7 +98,7 @@ KateDocManager::~KateDocManager ()
 
 KateDocManager *KateDocManager::self ()
 {
-  return KateApp::self()->kateDocumentManager ();
+  return KateApp::self()->documentManager ();
 }
 
 Kate::Document *KateDocManager::createDoc ()
@@ -107,7 +110,7 @@ Kate::Document *KateDocManager::createDoc ()
   m_docInfos.insert (doc, new KateDocumentInfo ());
 
   if (m_docList.count() < 2)
-    ((Kate::Document *)doc)->readConfig(kapp->config());
+    ((Kate::Document *)doc)->readConfig(KateApp::self()->config());
 
   emit documentCreated ((Kate::Document *)doc);
   emit m_documentManager->documentCreated ((Kate::Document *)doc);
@@ -124,7 +127,7 @@ void KateDocManager::deleteDoc (Kate::Document *doc)
     activeId = m_currentDoc->documentNumber ();
 
   if (m_docList.count() < 2)
-    doc->writeConfig(kapp->config());
+    doc->writeConfig(KateApp::self()->config());
 
   m_docInfos.remove (doc);
   m_docDict.remove (id);
@@ -227,7 +230,7 @@ bool KateDocManager::isOpen(KURL url)
   return findDocumentByUrl (url) != 0;
 }
 
-Kate::Document *KateDocManager::openURL (const KURL& url,const QString &encoding, uint *id)
+Kate::Document *KateDocManager::openURL (const KURL& url,const QString &encoding, uint *id, bool isTempFile)
 {
   // special handling if still only the first initial doc is there
   if (!documentList().isEmpty() && (documentList().count() == 1) && (!documentList().at(0)->isModified() && documentList().at(0)->url().isEmpty()))
@@ -242,12 +245,22 @@ Kate::Document *KateDocManager::openURL (const KURL& url,const QString &encoding
     if (id)
       *id=doc->documentNumber();
 
+    if ( isTempFile && !url.isEmpty() && url.isLocalFile() )
+    {
+      QFileInfo fi( url.path() );
+      if ( fi.exists() )
+      {
+        m_tempFiles[ doc->documentNumber() ] = qMakePair(url, fi.lastModified());
+        kdDebug(13001)<<"temporary file will be deleted after use unless modified: "<<url.prettyURL()<<endl;
+      }
+    }
+
     connect(doc, SIGNAL(modStateChanged(Kate::Document *)), this, SLOT(slotModChanged(Kate::Document *)));
 
     emit initialDocumentReplaced();
 
     return doc;
- }
+  }
 
   Kate::Document *doc = findDocumentByUrl (url);
   if ( !doc )
@@ -263,6 +276,16 @@ Kate::Document *KateDocManager::openURL (const KURL& url,const QString &encoding
   if (id)
     *id=doc->documentNumber();
 
+  if ( isTempFile && !url.isEmpty() && url.isLocalFile() )
+  {
+    QFileInfo fi( url.path() );
+    if ( fi.exists() )
+    {
+      m_tempFiles[ doc->documentNumber() ] = qMakePair(url, fi.lastModified());
+      kdDebug(13001)<<"temporary file will be deleted after use unless modified: "<<url.prettyURL()<<endl;
+    }
+  }
+
   return doc;
 }
 
@@ -277,9 +300,26 @@ bool KateDocManager::closeDocument(class Kate::Document *doc,bool closeURL)
   QPtrList<Kate::View> closeList;
   uint documentNumber = doc->documentNumber();
 
-  for (uint i=0; i < ((KateApp *)kapp)->mainWindows (); i++ )
+  for (uint i=0; i < KateApp::self()->mainWindows (); i++ )
   {
-     ((KateApp *)kapp)->kateMainWindow(i)->kateViewManager()->closeViews(documentNumber);
+    KateApp::self()->mainWindow(i)->viewManager()->closeViews(documentNumber);
+  }
+
+  if ( closeURL && m_tempFiles.contains( documentNumber ) )
+  {
+    QFileInfo fi( m_tempFiles[ documentNumber ].first.path() );
+    if ( fi.lastModified() <= m_tempFiles[ documentNumber ].second /*||
+         KMessageBox::questionYesNo( KateApp::self()->activeMainWindow(),
+            i18n("The supposedly temporary file %1 has been modified. "
+                "Do you want to delete it anyway?").arg(m_tempFiles[ documentNumber ].first.prettyURL()),
+            i18n("Delete File?") ) == KMessageBox::Yes*/ )
+    {
+      KIO::del( m_tempFiles[ documentNumber ].first, false, false );
+      kdDebug(13001)<<"Deleted temporary file "<<m_tempFiles[ documentNumber ].first<<endl;
+      m_tempFiles.remove( documentNumber );
+    }
+    else
+      kdWarning(13001)<<"The supposedly temporary file "<<m_tempFiles[ documentNumber ].first.prettyURL()<<" have been modified since loaded, and has not been deleted."<<endl;
   }
 
   deleteDoc (doc);
@@ -307,9 +347,9 @@ bool KateDocManager::closeAllDocuments(bool closeURL)
 
   QPtrList<Kate::Document> docs = m_docList;
 
-  for (uint i=0; i < ((KateApp *)kapp)->mainWindows (); i++ )
+  for (uint i=0; i < KateApp::self()->mainWindows (); i++ )
   {
-    ((KateApp *)kapp)->kateMainWindow(i)->kateViewManager()->setViewActivationBlocked(true);
+    KateApp::self()->mainWindow(i)->viewManager()->setViewActivationBlocked(true);
   }
 
   while (!docs.isEmpty() && res)
@@ -318,12 +358,12 @@ bool KateDocManager::closeAllDocuments(bool closeURL)
     else
       docs.remove ((uint)0);
 
-  for (uint i=0; i < ((KateApp *)kapp)->mainWindows (); i++ )
+  for (uint i=0; i < KateApp::self()->mainWindows (); i++ )
   {
-    ((KateApp *)kapp)->kateMainWindow(i)->kateViewManager()->setViewActivationBlocked(false);
+    KateApp::self()->mainWindow(i)->viewManager()->setViewActivationBlocked(false);
 
-    for (uint s=0; s < ((KateApp *)kapp)->kateMainWindow(i)->kateViewManager()->containers()->count(); s++)
-      ((KateApp *)kapp)->kateMainWindow(i)->kateViewManager()->containers()->at(s)->activateView (m_docList.at(0)->documentNumber());
+    for (uint s=0; s < KateApp::self()->mainWindow(i)->viewManager()->containers()->count(); s++)
+      KateApp::self()->mainWindow(i)->viewManager()->containers()->at(s)->activateView (m_docList.at(0)->documentNumber());
   }
 
   return res;
@@ -430,7 +470,13 @@ void KateDocManager::restoreDocumentList (KConfig* config)
   config->setGroup ("Open Documents");
   QString grp = config->group();
 
-  int count = config->readNumEntry("Count");
+  unsigned int count = config->readUnsignedNumEntry("Count", 0);
+
+  if (count == 0)
+  {
+    config->setGroup(prevGrp);
+    return;
+  }
 
   QProgressDialog *pd=new QProgressDialog(
         i18n("Reopening files from the last session..."),
@@ -439,8 +485,10 @@ void KateDocManager::restoreDocumentList (KConfig* config)
         0,
         "openprog");
 
+  pd->setCaption (KateApp::self()->makeStdCaption(i18n("Starting Up")));
+
   bool first = true;
-  for (int i=0; i < count; i++)
+  for (unsigned int i=0; i < count; i++)
   {
     config->setGroup(QString("Document %1").arg(i));
     Kate::Document *doc = 0;
@@ -457,7 +505,7 @@ void KateDocManager::restoreDocumentList (KConfig* config)
     config->setGroup (grp);
 
     pd->setProgress(pd->progress()+1);
-    kapp->processEvents();
+    KateApp::self()->processEvents();
   }
 
   delete pd;
@@ -557,4 +605,5 @@ bool KateDocManager::computeUrlMD5(const KURL &url, QCString &result)
 
   return true;
 }
+
 // kate: space-indent on; indent-width 2; replace-tabs on;
