@@ -56,7 +56,7 @@ class KDE_EXPORT PluginConfigInterface
 };
 
 class Plugin;
-PluginConfigInterface *pluginConfigInterface (Plugin *plugin);
+KDE_EXPORT PluginConfigInterface *pluginConfigInterface (Plugin *plugin);
 
 }
 
