@@ -142,6 +142,8 @@ QStringList TypesListItem::embedServices() const
 
 void TypesListItem::getServiceOffers( QStringList & appServices, QStringList & embedServices ) const
 {
+  KServiceTypeProfile::setConfigurationMode();
+
   KServiceTypeProfile::OfferList offerList =
     KServiceTypeProfile::offers(m_mimetype->name(), "Application");
   QValueListIterator<KServiceOffer> it(offerList.begin());
@@ -152,6 +154,8 @@ void TypesListItem::getServiceOffers( QStringList & appServices, QStringList & e
   offerList = KServiceTypeProfile::offers(m_mimetype->name(), "KParts/ReadOnlyPart");
   for ( it = offerList.begin(); it != offerList.end(); ++it)
     embedServices.append((*it).service()->desktopEntryPath());
+
+  KServiceTypeProfile::unsetConfigurationMode();
 }
 
 bool TypesListItem::isMimeTypeDirty() const
@@ -321,9 +325,11 @@ void TypesListItem::sync()
 
   // Handle removed services
 
+  KServiceTypeProfile::setConfigurationMode();
   KServiceTypeProfile::OfferList offerList =
     KServiceTypeProfile::offers(m_mimetype->name(), "Application");
   offerList += KServiceTypeProfile::offers(m_mimetype->name(), "KParts/ReadOnlyPart");
+  KServiceTypeProfile::unsetConfigurationMode();
 
   QValueListIterator<KServiceOffer> it_srv(offerList.begin());
 
