@@ -477,7 +477,16 @@ void MouseConfig::setHandedness(int val)
 
 void MouseConfig::load()
 {
+   load( false );
+}
+
+void MouseConfig::load( bool useDefaults )
+{
+
   KConfig config( "kcminputrc", true );
+
+  config.setReadDefaults( useDefaults );
+
   settings->load(&config);
 
   tab1->rightHanded->setEnabled(settings->handedEnabled);
@@ -538,7 +547,7 @@ void MouseConfig::load()
   themetab->load();
 
   checkAccess();
-  changed();
+  changed( useDefaults );
 }
 
 void MouseConfig::save()
@@ -590,32 +599,7 @@ void MouseConfig::save()
 
 void MouseConfig::defaults()
 {
-    setThreshold(2);
-    setAccel(2);
-    setHandedness(RIGHT_HANDED);
-    tab1->cbScrollPolarity->setChecked( false );
-    doubleClickInterval->setValue(400);
-    dragStartTime->setValue(500);
-    dragStartDist->setValue(4);
-    wheelScrollLines->setValue(3);
-    tab1->doubleClick->setChecked( !KDE_DEFAULT_SINGLECLICK );
-    tab1->cbAutoSelect->setChecked( KDE_DEFAULT_AUTOSELECTDELAY != -1 );
-    tab1->slAutoSelect->setValue( KDE_DEFAULT_AUTOSELECTDELAY == -1 ? 50 : KDE_DEFAULT_AUTOSELECTDELAY );
-    tab1->singleClick->setChecked( KDE_DEFAULT_SINGLECLICK );
-    tab1->cbVisualActivate->setChecked( KDE_DEFAULT_VISUAL_ACTIVATE );
-    tab1->cb_pointershape->setChecked(KDE_DEFAULT_CHANGECURSOR);
-    slotClick();
-
-  mouseKeys->setChecked(false);
-  mk_delay->setValue(160);
-  mk_interval->setValue(5);
-  mk_time_to_max->setValue(5000);
-  mk_max_speed->setValue(1000);
-  mk_curve->setValue(0);
-
-  checkAccess();
-
-  changed();
+   load( true );
 }
 
 void MouseConfig::slotClick()
