@@ -87,13 +87,20 @@ void KeyModule::initGUI()
 	connect( m_pModifiers, SIGNAL(changed(bool)), SIGNAL(changed(bool)) );
 }
 
-// Called when [Reset] is pressed
 void KeyModule::load()
+{
+   load( false );
+}
+
+// Called when [Reset] is pressed
+void KeyModule::load( bool useDefaults )
 {
 	kdDebug(125) << "KeyModule::load()" << endl;
 	m_pShortcuts->load();
 	m_pCommandShortcuts->load();
-	m_pModifiers->load();
+	m_pModifiers->load( useDefaults );
+
+   emit changed( useDefaults );
 }
 
 // When [Apply] or [OK] are clicked.
