@@ -142,6 +142,15 @@ void XAutoLock::resetTrigger()
     mTrigger = time(0) + mTimeout;
 }
 
+//---------------------------------------------------------------------------
+//
+// Move the trigger time in order to postpone (repeat) emitting of timeout().
+//
+void XAutoLock::postpone()
+{
+    mTrigger = time(0) + 60; // delay by 60sec
+}
+
 //---------------------------------------------------------------------------
 //
 // Set the remaining time to 't', if it's shorter than already set.
@@ -192,6 +201,7 @@ void XAutoLock::timerEvent(QTimerEvent *ev)
 
     bool activate = false;
 
+    //kdDebug() << now << " " << mTrigger << endl;
     if (now >= mTrigger)
     {
         resetTrigger();
@@ -202,6 +212,8 @@ void XAutoLock::timerEvent(QTimerEvent *ev)
     BOOL on;
     CARD16 state;
     DPMSInfo( qt_xdisplay(), &state, &on );
+
+    //kdDebug() << "DPMSInfo " << state << " " << on << endl;
     // If DPMS is active, it makes XScreenSaverQueryInfo() report idle time
     // that is always smaller than DPMS timeout (X bug I guess). So if DPMS
     // saving is active, simply always activate our saving too, otherwise
@@ -210,6 +222,7 @@ void XAutoLock::timerEvent(QTimerEvent *ev)
         activate = true;
     if(!on && mDPMS) {
         activate = false;
+        XForceScreenSaver(qt_xdisplay(), ScreenSaverReset );
         resetTrigger();
     }
 #endif
@@ -217,9 +230,11 @@ void XAutoLock::timerEvent(QTimerEvent *ev)
 #ifdef HAVE_XSCREENSAVER
     static XScreenSaverInfo* mitInfo = 0;
     if (!mitInfo) mitInfo = XScreenSaverAllocInfo ();
-    XScreenSaverQueryInfo (qt_xdisplay(), DefaultRootWindow (qt_xdisplay()), mitInfo);
-    if (mitInfo->state == ScreenSaverDisabled)
-	activate = false;
+    if (XScreenSaverQueryInfo (qt_xdisplay(), DefaultRootWindow (qt_xdisplay()), mitInfo)) {
+        //kdDebug() << "XScreenSaverQueryInfo " << mitInfo->state << " " << ScreenSaverDisabled << endl;
+        if (mitInfo->state == ScreenSaverDisabled)
+	    activate = false;
+    }
 #endif
 
     if(mActive && activate)
