@@ -83,7 +83,8 @@ RememberIndirectClient( ARRAY8Ptr clientAddress, CARD16 connectionType )
 		if (XdmcpARRAY8Equal( clientAddress, &i->client ) &&
 		    connectionType == i->connectionType)
 			return 1;
-	i = (IndirectUsersPtr)Malloc( sizeof(IndirectUsersRec) );
+	if (!(i = (IndirectUsersPtr)Malloc( sizeof(IndirectUsersRec) )))
+		return 0;
 	if (!XdmcpCopyARRAY8( clientAddress, &i->client )) {
 		free( (char *)i );
 		return 0;
