@@ -121,8 +121,9 @@ conv_auto( int what, const char *prompt ATTR_UNUSED )
 static void
 DoAutoLogon( void )
 {
-	StrDup( &curuser, td->autoUser );
-	StrDup( &curpass, td->autoPass );
+	ReStr( &curuser, td->autoUser );
+	ReStr( &curpass, td->autoPass );
+	ReStr( &curtype, "classic" );
 	cursource = PWSRC_AUTOLOGIN;
 }
 
@@ -141,7 +142,9 @@ AutoLogon( Time_t tdiff )
 		td->hstent->npass = 0;
 		newdmrc = td->hstent->nargs;
 		td->hstent->nargs = 0;
+		ReStr( &curtype, "classic" );
 		cursource = (td->hstent->rLogin == 1) ? PWSRC_RELOGIN : PWSRC_MANUAL;
+		return 1;
 	} else if (*td->autoUser && !td->autoDelay && (tdiff > 0 || td->autoAgain))
 	{
 		unsigned int lmask;
@@ -153,11 +156,9 @@ AutoLogon( Time_t tdiff )
 		if (lmask & ShiftMask)
 			return 0;
 		DoAutoLogon();
-	} else {
-		cursource = PWSRC_MANUAL;
-		return 0;
+		return 1;
 	}
-	return 1;
+	return 0;
 }
 
 
@@ -369,6 +370,7 @@ CtrlGreeterWait( int wreply )
 			if (curtype) free( curtype );
 			curtype = GRecvStr();
 			Debug( " type %\"s\n", curtype );
+			cursource = PWSRC_MANUAL;
 			if (Verify( conv_interact, rootok )) {
 				Debug( " -> return success\n" );
 				GSendInt( V_OK );
@@ -378,7 +380,6 @@ CtrlGreeterWait( int wreply )
 		case G_AutoLogin:
 			Debug( "G_AutoLogin\n" );
 			DoAutoLogon();
-			StrDup( &curtype, "classic" );
 			if (Verify( conv_auto, FALSE )) {
 				Debug( " -> return success\n" );
 				GSendInt( V_OK );
@@ -524,7 +525,7 @@ ManageSession( struct display *d )
 {
 	int ex, cmd;
 	volatile int clientPid = 0;
-	Time_t tdiff;
+	volatile Time_t tdiff = 0;
 
 	td = d;
 	Debug( "ManageSession %s\n", d->name );
@@ -560,12 +561,12 @@ ManageSession( struct display *d )
 			LogError( "Received unknown command %d from greeter\n", cmd );
 			CloseGreeter( TRUE );
 		}
+		goto regreet;
 	}
 
-	tdiff = td->autoAgain ? 
-	           1 : time( 0 ) - td->hstent->lastExit - td->openDelay;
+	tdiff = time( 0 ) - td->hstent->lastExit - td->openDelay;
 	if (AutoLogon( tdiff )) {
-		if (!StrDup( &curtype, "classic" ) || !Verify( conv_auto, FALSE ))
+		if (!Verify( conv_auto, FALSE ))
 			goto gcont;
 		if (greeter)
 			GSendInt( V_OK );
@@ -585,8 +586,9 @@ ManageSession( struct display *d )
 #endif
 		for (;;) {
 			Debug( "ManageSession, greeting, tdiff = %d\n", tdiff );
-			GSendInt( *td->autoUser && td->autoDelay && tdiff > 0 ?
-			             G_GreetTimed : G_Greet );
+			GSendInt( (*td->autoUser && td->autoDelay &&
+			           (tdiff > 0 || td->autoAgain)) ?
+			              G_GreetTimed : G_Greet );
 		  gcont:
 			cmd = CtrlGreeterWait( TRUE );
 #ifdef XDMCP
