@@ -673,7 +673,7 @@ static const char def_session1[] =
 "    xsess_tmp=";
 static const char def_session2[] =
 "\n"
-"    $SHELL -c \"if (-f /etc/csh.login) source /etc/csh.login; if (-f ~/.login) source ~/.login; /bin/sh -c export > $xsess_tmp\"\n"
+"    $SHELL -c \"if (-f /etc/csh.login) source /etc/csh.login; if (-f ~/.login) source ~/.login; /bin/sh -c export >! $xsess_tmp\"\n"
 "    . $xsess_tmp\n"
 "    rm -f $xsess_tmp\n"
 "    ;;\n"
@@ -1684,10 +1684,10 @@ mk_session( Entry *ce, Section *cs ATTR_UNUSED )
 		linkfile( ce );
 	else {
 		tmpf = locate( "mktemp" ) ?
-		           "`mktemp`" :
+		           "`mktemp /tmp/xsess-env-XXXXXX`" :
 		           locate( "tempfile" ) ?
 		               "`tempfile`" :
-		               "$HOME/.xsession-env-$$";
+		               "$HOME/.xsession-env-$DISPLAY";
 		ASPrintf( &def_session, "%s%s%s", def_session1, tmpf, def_session2 );
 		ce->value = KDMCONF "/Xsession";
 		ce->active = ce->written = 1;
@@ -2239,7 +2239,7 @@ mergeKdmRcNewer( const char *path )
 		free( p );
 		return 0;
 	}
-	printf( "Information: reading old kdmrc %s (from kde >= 2.2.x)\n", p );
+	printf( "Information: reading current kdmrc %s (from kde >= 2.2.x)\n", p );
 	free( p );
 
 	for (cs = rootsect; cs; cs = cs->next) {
@@ -2298,10 +2298,10 @@ mergeKdmRcNewer( const char *path )
 		if (is22conf( path )) {
 			/* work around 2.2.x defaults borkedness */
 			applydefs( kdmdefs_eq_22, as(kdmdefs_eq_22), path );
-			printf( "Information: old kdmrc is from kde 2.2\n" );
+			printf( "Information: current kdmrc is from kde 2.2\n" );
 		} else {
 			applydefs( kdmdefs_ge_30, as(kdmdefs_ge_30), path );
-			printf( "Information: old kdmrc is from kde 3.0\n" );
+			printf( "Information: current kdmrc is from kde 3.0\n" );
 		}
 #ifdef XDMCP
 		/* work around minor <= 3.0.x defaults borkedness */
@@ -2311,7 +2311,7 @@ mergeKdmRcNewer( const char *path )
 		int ma, mi;
 		sscanf( cp, "%d.%d", &ma, &mi );
 		oldver = (ma << 8) | mi;
-		printf( "Information: old kdmrc is from kde >= 3.1 (config version %d.%d)\n", ma, mi );
+		printf( "Information: current kdmrc is from kde >= 3.1 (config version %d.%d)\n", ma, mi );
 		applydefs( kdmdefs_ge_30, as(kdmdefs_ge_30), path );
 		applydefs( kdmdefs_ge_31, as(kdmdefs_ge_31), path );
 	}
@@ -2520,7 +2520,7 @@ mergeXdmCfg( const char *path )
 
 	ASPrintf( &p, "%s/xdm-config", path );
 	if ((db = XrmGetFileDatabase( p ))) {
-		printf( "Information: reading old xdm config file %s\n", p );
+		printf( "Information: reading current xdm config file %s\n", p );
 		usedFile( p );
 		free( p );
 		XrmEnumerateDatabase( db, &empty, &empty, XrmEnumAllLevels,
