@@ -657,7 +657,7 @@ KStdGreeter::KStdGreeter()
 	goButton = new QPushButton( i18n("L&ogin"), this );
 	goButton->setDefault( true );
 	connect( goButton, SIGNAL(clicked()), SLOT(accept()) );
-	QPushButton *menuButton = new QPushButton( i18n("&Menu"), this );
+	menuButton = new QPushButton( i18n("&Menu"), this );
 	//helpButton
 
 	QWidget *prec;
@@ -730,6 +730,7 @@ void
 KStdGreeter::verifyFailed()
 {
 	goButton->setEnabled( false );
+	menuButton->setEnabled( false );
 	if (userView)
 		userView->setEnabled( false );
 	inherited::verifyFailed();
@@ -739,6 +740,7 @@ void
 KStdGreeter::verifyRetry()
 {
 	goButton->setEnabled( true );
+	menuButton->setEnabled( true );
 	if (userView)
 		userView->setEnabled( true );
 }
