@@ -24,7 +24,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #ifndef __dockbarextension_h__
 #define __dockbarextension_h__
 
-#include <qptrlist.h>
+#include <qvaluevector.h>
 #include <kpanelextension.h>
 #include "dockcontainer.h"
 
@@ -62,7 +62,7 @@ protected:
     void mouseMoveEvent(QMouseEvent *);
 private:
     KWinModule* kwin_module;
-    QPtrList<DockContainer> containers;
+    DockContainer::Vector containers;
 
     // handle the dragging of applets
     DockContainer *dragging_container, *original_container;
