@@ -97,9 +97,9 @@ KasTaskItem::KasTaskItem( KasTasker *parent, Task::Ptr task )
 {
     setIcon( icon() );
     setAttention( task->demandsAttention() );
-    updateTask();
+    updateTask(false);
 
-    connect( task, SIGNAL( changed() ), this, SLOT( updateTask() ) );
+    connect( task, SIGNAL( changed(bool) ), this, SLOT( updateTask(bool) ) );
     connect( task, SIGNAL( activated() ), this, SLOT( startAutoThumbnail() ) );
     connect( task, SIGNAL( deactivated() ), this, SLOT( stopAutoThumbnail() ) );
     connect( task, SIGNAL( iconChanged() ), this, SLOT( iconChanged() ) );
@@ -165,8 +165,13 @@ void KasTaskItem::checkAttention()
     setAttention( task_->demandsAttention() );
 }
 
-void KasTaskItem::updateTask()
+void KasTaskItem::updateTask(bool geometryChangeOnly)
 {
+    if (geometryChangeOnly)
+    {
+        return;
+    }
+
     bool updates = kasbar()->isUpdatesEnabled();
     kasbar()->setUpdatesEnabled( false );
 
