@@ -25,15 +25,17 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #include <qtimer.h>
 
 #include <dcopclient.h>
-#include <karrowbutton.h>
 #include <kapplication.h>
 #include <kdebug.h>
+#include <kiconloader.h>
 #include <kwindowlistmenu.h>
 
 #include <X11/X.h>
 #include <X11/Xlib.h>
 #include <X11/Xutil.h>
 
+#include "simplebutton.h"
+
 #include "taskbar.h"
 #include "taskbarsettings.h"
 
@@ -89,49 +91,52 @@ void TaskBarContainer::configure()
     setFont(TaskBarSettings::taskbarFont());
     showWindowListButton = TaskBarSettings::showWindowListBtn();
 
-    if ( showWindowListButton )
-    {
-        if (windowListButton == 0)
-        {
-            // window list button
-            windowListButton = new KArrowButton( this );
-            windowListMenu= new KWindowListMenu;
-            connect( windowListButton, SIGNAL( pressed() ), SLOT( showWindowListMenu() ) );
-            connect( windowListMenu, SIGNAL( aboutToHide() ), SLOT( windowListMenuAboutToHide() ) );
-
-            // geometry
-            windowListButton->setMinimumSize( WINDOWLISTBUTTON_SIZE, WINDOWLISTBUTTON_SIZE );
-            switch (direction)
-            {
-                case KPanelApplet::Up:
-                    windowListButton->setArrowType(UpArrow);
-                    windowListButton->setMaximumHeight(BUTTON_MAX_WIDTH);
-                    break;
-                case KPanelApplet::Down:
-                    windowListButton->setArrowType(DownArrow);
-                    windowListButton->setMaximumHeight(BUTTON_MAX_WIDTH);
-                    break;
-                case KPanelApplet::Left:
-                    windowListButton->setArrowType(LeftArrow);
-                    windowListButton->setMaximumWidth(BUTTON_MAX_WIDTH);
-                    break;
-                case KPanelApplet::Right:
-                    windowListButton->setArrowType(RightArrow);
-                    windowListButton->setMaximumWidth(BUTTON_MAX_WIDTH);
-                    break;
-            }
-
-            layout->insertWidget( 0, windowListButton );
-            windowListButton->show();
-        }
-    }
-    else
+    if (!showWindowListButton)
     {
         delete windowListButton;
         windowListButton = 0;
         delete windowListMenu;
         windowListMenu = 0;
     }
+    else if (windowListButton == 0)
+    {
+        // window list button
+        windowListButton = new SimpleButton(this);
+        windowListMenu= new KWindowListMenu;
+        connect(windowListButton, SIGNAL(pressed()),
+                SLOT(showWindowListMenu()));
+        connect(windowListMenu, SIGNAL(aboutToHide()),
+                SLOT(windowListMenuAboutToHide()));
+
+        // geometry
+        QString icon;
+        switch (direction)
+        {
+            case KPanelApplet::Up:
+                icon = "1uparrow";
+                windowListButton->setMaximumHeight(BUTTON_MAX_WIDTH);
+                break;
+            case KPanelApplet::Down:
+                icon = "1downarrow";
+                windowListButton->setMaximumHeight(BUTTON_MAX_WIDTH);
+                break;
+            case KPanelApplet::Left:
+                icon = "1leftarrow";
+                windowListButton->setMaximumWidth(BUTTON_MAX_WIDTH);
+                break;
+            case KPanelApplet::Right:
+                icon = "1rightarrow";
+                windowListButton->setMaximumWidth(BUTTON_MAX_WIDTH);
+                break;
+        }
+
+        windowListButton->setPixmap(kapp->iconLoader()->loadIcon(icon,
+                                                                 KIcon::Panel,
+                                                                 16));
+        windowListButton->setMinimumSize(windowListButton->sizeHint());
+        layout->insertWidget(0, windowListButton);
+        windowListButton->show();
+    }
 }
 
 void TaskBarContainer::configChanged()
@@ -159,26 +164,34 @@ void TaskBarContainer::preferences()
     kapp->dcopClient()->send("kicker", "kicker", "showTaskBarConfig()", data);
 }
 
-void TaskBarContainer::orientationChange( Orientation o )
+void TaskBarContainer::orientationChange(Orientation o)
 {
-    if( o == Horizontal ) {
+    if (o == Horizontal)
+     {
         if (windowListButton)
         {
-            windowListButton->setFixedWidth( WINDOWLISTBUTTON_SIZE );
-            windowListButton->setMaximumHeight( BUTTON_MAX_WIDTH );
+            windowListButton->setFixedWidth(WINDOWLISTBUTTON_SIZE);
+            windowListButton->setMaximumHeight(BUTTON_MAX_WIDTH);
         }
-        layout->setDirection( QApplication::reverseLayout() ?
-                              QBoxLayout::RightToLeft :
-                              QBoxLayout::LeftToRight );
-    } else {
+        layout->setDirection(QApplication::reverseLayout() ?
+                                QBoxLayout::RightToLeft :
+                                QBoxLayout::LeftToRight);
+    }
+    else
+    {
         if (windowListButton)
         {
-            windowListButton->setMaximumWidth( BUTTON_MAX_WIDTH );
-            windowListButton->setFixedHeight( WINDOWLISTBUTTON_SIZE );
+            windowListButton->setMaximumWidth(BUTTON_MAX_WIDTH);
+            windowListButton->setFixedHeight(WINDOWLISTBUTTON_SIZE);
         }
-        layout->setDirection( QBoxLayout::TopToBottom );
+        layout->setDirection(QBoxLayout::TopToBottom);
+    }
+
+    taskBar->setOrientation(o);
+    if (windowListButton)
+    {
+        windowListButton->setOrientation(o);
     }
-    taskBar->setOrientation( o );
     layout->activate();
 }
 
@@ -187,18 +200,23 @@ void TaskBarContainer::popupDirectionChange(KPanelApplet::Direction d)
     direction = d;
     ArrowType at = UpArrow;
 
+    QString icon;
     switch (d)
     {
         case KPanelApplet::Up:
+            icon = "1uparrow";
             at = UpArrow;
             break;
         case KPanelApplet::Down:
+            icon = "1downarrow";
             at = DownArrow;
             break;
         case KPanelApplet::Left:
+            icon = "1leftarrow";
             at = LeftArrow;
             break;
         case KPanelApplet::Right:
+            icon = "1rightarrow";
             at = RightArrow;
             break;
     }
@@ -207,7 +225,10 @@ void TaskBarContainer::popupDirectionChange(KPanelApplet::Direction d)
 
     if (windowListButton)
     {
-        windowListButton->setArrowType(at);
+        windowListButton->setPixmap(kapp->iconLoader()->loadIcon(icon,
+                                                                 KIcon::Panel,
+                                                                 16));
+        windowListButton->setMinimumSize(windowListButton->sizeHint());
     }
 }
 
