@@ -61,7 +61,7 @@ class KManPart : public KHTMLPart
    Q_OBJECT
    public:
       KManPart( QWidget * parent, const char * name = 0L );
-      KParts::BrowserExtension * extension() {return m_extension;};
+      KParts::BrowserExtension * extension() {return m_extension;}
 
    public slots:
       virtual bool openURL( const KURL &url );
