@@ -497,7 +497,7 @@ void KonqAboutPage::urlSelected( const QString &url, int button, int state, cons
 	if ( KMessageBox::questionYesNo( widget(),
 					 i18n("Do you want to disable showing "
 					      "the introduction in the webbrowsing profile?"),
-					 i18n("Faster Startup?") )
+					 i18n("Faster Startup?"),i18n("Disable"),i18n("Keep") )
 	     == KMessageBox::Yes )
 	{
 	    QString profile = locateLocal("data", "konqueror/profiles/webbrowsing");
