@@ -1,4 +1,4 @@
-// -*- mode:cperl; cperl-indent-level:4; cperl-continued-statement-offset:4; indent-tabs-mode:nil -*-
+// -*- indent-tabs-mode:nil -*-
 // vim: set ts=4 sts=4 sw=4 et:
 /* This file is part of the KDE project
    Copyright (C) 2000 David Faure <faure@kde.org>
@@ -15,8 +15,8 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.
 */
 
 #include "toplevel.h"
@@ -29,7 +29,6 @@
 #include <qpainter.h>
 
 #include <kdebug.h>
-#include <klocale.h>
 
 #include <krfcdate.h>
 #include <kcharsets.h>
@@ -46,6 +45,22 @@ TestLinkItrHolder::TestLinkItrHolder()
 
 void TestLinkItrHolder::doItrListChanged() {
     KEBApp::self()->setCancelTestsEnabled(count() > 0);
+    if(count() == 0)
+    {
+        kdDebug()<<"Notifing managers "<<m_affectedBookmark<<endl;
+        CurrentMgr::self()->notifyManagers(CurrentMgr::bookmarkAt(m_affectedBookmark).toGroup());
+        m_affectedBookmark = QString::null;
+    }
+}
+
+void TestLinkItrHolder::addAffectedBookmark( const QString & address )
+{
+    kdDebug()<<"addAffectedBookmark "<<address<<endl;
+    if(m_affectedBookmark.isNull())
+        m_affectedBookmark = address;
+    else
+        m_affectedBookmark = KBookmark::commonParent(m_affectedBookmark, address);
+    kdDebug()<<" m_affectedBookmark is now "<<m_affectedBookmark<<endl;
 }
 
 /* -------------------------- */
@@ -73,6 +88,7 @@ void TestLinkItr::doAction() {
 
     m_job = KIO::get(curBk().url(), true, false);
     m_job->addMetaData("errorPage", "true");
+    m_job->addMetaData( QString("cookies"), QString("none") );
 
     connect(m_job, SIGNAL( result( KIO::Job *)),
             this, SLOT( slotJobResult(KIO::Job *)));
@@ -143,6 +159,7 @@ void TestLinkItr::slotJobResult(KIO::Job *job) {
     }
 
     curItem()->modUpdate();
+    holder()->addAffectedBookmark(KBookmark::parentAddress(curBk().address()));
     delayedEmitNextOne();
 }
 
@@ -178,14 +195,6 @@ void TestLinkItrHolder::resetToValue(const QString &url, const QString &oldValue
 
 /* -------------------------- */
 
-static QString mkTimeStr(int b) {
-    QDateTime dt;
-    dt.setTime_t(b);
-    return (dt.daysTo(QDateTime::currentDateTime()) > 31)
-        ? KGlobal::locale()->formatDate(dt.date(), false)
-        : KGlobal::locale()->formatDateTime(dt, false);
-}
-
 QString TestLinkItrHolder::calcPaintStyle(const QString &url, KEBListViewItem::PaintStyle &_style, 
                                           const QString &nVisit, const QString &Modify) {
     bool newModValid = false;
@@ -266,7 +275,7 @@ QString TestLinkItrHolder::calcPaintStyle(const QString &url, KEBListViewItem::P
 
     } else if (!newModStr.isNull() && (newMod > visit)) { 
         // if modify time greater than last visit, show bold modify time
-        statusStr = mkTimeStr(newMod);
+        statusStr = CurrentMgr::makeTimeStr(newMod);
         if (initial) {
             style = KEBListViewItem::GreyBoldStyle;
         } else {
@@ -275,7 +284,7 @@ QString TestLinkItrHolder::calcPaintStyle(const QString &url, KEBListViewItem::P
 
     } else if (visit != 0) { 
         // modify time not greater than last visit, show last visit time
-        statusStr = mkTimeStr(visit);
+        statusStr = CurrentMgr::makeTimeStr(visit);
         if (initial) {
                 style = KEBListViewItem::GreyStyle;
         } else {
@@ -339,7 +348,6 @@ void KEBListViewItem::nsPut(const QString &newModDate) {
     m_bookmark.internalElement().setAttribute(NetscapeInfoAttribute, blah);
     TestLinkItrHolder::self()->setMod(m_bookmark.url().url(), newModDate);
     setText(KEBListView::StatusColumn, newModDate);
-    KEBApp::self()->setModifiedFlag(true);
 }
 
 // KEBListViewItem !!!!!!!!!!!
