@@ -253,14 +253,14 @@ void KonqFrameTabs::setTitle( const QString &title , QWidget* sender)
   setTabLabel( sender,title );
 }
 
-void KonqFrameTabs::setTabIcon( const QString &url, QWidget* sender )
+void KonqFrameTabs::setTabIcon( const KURL &url, QWidget* sender )
 {
   //kdDebug(1202) << "KonqFrameTabs::setTabIcon( " << url << " , " << sender << " )" << endl;
   QIconSet iconSet;
   if (m_permanentCloseButtons)
     iconSet =  SmallIcon( "fileclose" );
   else
-    iconSet =  SmallIconSet( KonqPixmapProvider::self()->iconNameFor( url ) );
+    iconSet =  SmallIconSet( KonqPixmapProvider::self()->iconNameFor( url.url() ) );
   if (tabIconSet( sender ).pixmap().serialNumber() != iconSet.pixmap().serialNumber())
     setTabIconSet( sender, iconSet );
 }
@@ -291,7 +291,7 @@ void KonqFrameTabs::insertChildFrame( KonqFrameBase* frame, int index )
       KonqView* activeChildView = frame->activeChildView();
       if (activeChildView != 0L) {
         activeChildView->setCaption( activeChildView->caption() );
-        activeChildView->setTabIcon( activeChildView->url().url() );
+        activeChildView->setTabIcon( activeChildView->url() );
       }
       if (showTabBar)
           setTabBarHidden(false);
@@ -417,7 +417,7 @@ void KonqFrameTabs::refreshSubPopupMenuTab()
     }
     m_pSubPopupMenuTab->insertSeparator();
     m_closeOtherTabsId =
-      m_pSubPopupMenuTab->insertItem( SmallIconSet( "tab_remove" ),
+      m_pSubPopupMenuTab->insertItem( SmallIconSet( "tab_remove_other" ),
 				      i18n( "Close &Other Tabs" ),
 				      m_pViewManager->mainWindow(),
 				      SLOT( slotRemoveOtherTabsPopup() ),
