@@ -40,6 +40,10 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
 #include "server.h"
 
+#ifdef HAVE_SYS_TIME_H
+#include <sys/time.h>
+#endif
+
 #include <unistd.h>
 
 #include <qtimer.h>
@@ -332,6 +336,8 @@ QStringList KSMServer::windowWmCommand(WId w)
             return QStringList() << "firefox";
         if( command.endsWith( "thunderbird-bin" ))
             return QStringList() << "thunderbird";
+        if( command.endsWith( "sunbird-bin" ))
+            return QStringList() << "sunbird";
     }
     return ret;
 }
