@@ -14,12 +14,11 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
     KSysGuard is currently maintained by Chris Schlaeger <cs@kde.org>.
     Please do not commit any changes without consulting me first. Thanks!
 
-    $Id: FancyPlotter.cc,v 1.11 2003/03/07 22:08:24 waba Exp $
 */
 
 #include <qdom.h>
@@ -32,27 +31,26 @@
 
 #include <ksgrd/SensorManager.h>
 #include <ksgrd/StyleEngine.h>
-
+#include "SensorDisplay.h"
 #include "FancyPlotterSettings.h"
 
 #include "FancyPlotter.h"
 
 FancyPlotter::FancyPlotter( QWidget* parent, const char* name,
                             const QString &title, double, double,
-                            bool nf)
-  : KSGRD::SensorDisplay( parent, name, title )
+                            bool nf, bool isApplet)
+  : KSGRD::SensorDisplay( parent, name, title, nf, isApplet )
 {
   mBeams = 0;
-  setNoFrame( nf );
+  mSettingsDialog = 0;
 
   if ( noFrame() ) {
     mPlotter = new SignalPlotter( this );
     mPlotter->setShowTopBar( true );
-	} else
+  } else
     mPlotter = new SignalPlotter( frame() );
-
-  if ( !title.isEmpty() )
-    mPlotter->setTitle( title );
+  mPlotter->setTitle( title );
+  mPlotter->setThinFrame(!isApplet);   //if we aren't an applet, draw a thin white frame on the left and bottom, for a 3d effect
 
   setMinimumSize( sizeHint() );
 
@@ -71,6 +69,9 @@ FancyPlotter::~FancyPlotter()
 
 void FancyPlotter::configureSettings()
 {
+  if(mSettingsDialog) {
+    return;
+  }
   mSettingsDialog = new FancyPlotterSettings( this );
 
   mSettingsDialog->setTitle( title() );
@@ -99,7 +100,7 @@ void FancyPlotter::configureSettings()
   QValueList< QStringList > list;
   for ( uint i = 0; i < mBeams; ++i ) {
     QStringList entry;
-    entry << QString( "%1" ).arg( i + 1 );
+    entry << QString::number(i);
     entry << sensors().at( i )->hostName();
     entry << KSGRD::SensorMgr->translateSensor( sensors().at( i )->name() );
     entry << KSGRD::SensorMgr->translateUnit( sensors().at( i )->unit() );
@@ -111,11 +112,14 @@ void FancyPlotter::configureSettings()
   mSettingsDialog->setSensors( list );
 
   connect( mSettingsDialog, SIGNAL( applyClicked() ), SLOT( applySettings() ) );
+  connect( mSettingsDialog, SIGNAL( okClicked() ), SLOT( applySettings() ) );
+  connect( mSettingsDialog, SIGNAL( finished() ), SLOT( killDialog() ) );
 
-  if ( mSettingsDialog->exec() )
-    applySettings();
+  mSettingsDialog->show(); 
+}
 
-  delete mSettingsDialog;
+void FancyPlotter::killDialog() { 
+  mSettingsDialog->delayedDestruct();
   mSettingsDialog = 0;
 }
 
@@ -159,32 +163,24 @@ void FancyPlotter::applySettings()
 
   mPlotter->setBackgroundColor( mSettingsDialog->backgroundColor() );
 
-  /* Iterate through registered sensors and through the items of the
-   * listview. Where a sensor cannot be matched, it is removed. */
-  uint delCount = 0;
+
+  QValueList<int> orderOfSensors = mSettingsDialog->order();
+  QValueList<int> deletedSensors = mSettingsDialog->deleted();
+  mSettingsDialog->clearDeleted();
+  mSettingsDialog->resetOrder();
+  QValueList< int >::Iterator itDelete;
+  for ( itDelete = deletedSensors.begin(); itDelete != deletedSensors.end(); ++itDelete )
+    removeSensor(*itDelete);
+
+  QValueList< int >::Iterator itOrder;
+  mPlotter->reorderBeams(orderOfSensors);
+  reorderSensors(orderOfSensors);
 
   QValueList< QStringList > list = mSettingsDialog->sensors();
   QValueList< QStringList >::Iterator it;
 
-  for ( uint i = 0; i < sensors().count(); ++i ) {
-    bool found = false;
-    for ( it = list.begin(); it != list.end(); ++it ) {
-      if ( (*it)[ 0 ].toInt() == (int)( i + 1 + delCount ) ) {
-        mPlotter->beamColors()[ i ] = QColor( (*it)[ 5 ] );
-        found = true;
-        if ( delCount > 0 )
-          (*it)[ 0 ] = QString( "%1" ).arg( i + 1 );
-        continue;
-      }
-    }
-
-    if ( !found ) {
-      if ( removeSensor(i) ) {
-        i--;
-        delCount++;
-      }
-    }
-  }
+  for ( uint i = 0; i < sensors().count(); ++i )
+        mPlotter->beamColors()[ i ] = QColor( list[i][ 5 ] );
 
   mPlotter->repaint();
   setModified( true );
