@@ -200,10 +200,14 @@ bool Workspace::workspaceEvent( XEvent * e )
         XUngrabKeyboard( qt_xdisplay(), qt_x_time );
         }
 
-    if ( e->type == PropertyNotify || e->type == ClientMessage ) 
+    if( e->type == PropertyNotify || e->type == ClientMessage )
         {
-        if ( netCheck( e ) )
-            return TRUE;
+        unsigned long dirty[ NETRootInfo::PROPERTIES_SIZE ];
+        rootInfo->event( e, dirty, NETRootInfo::PROPERTIES_SIZE );
+        if( dirty[ NETRootInfo::PROTOCOLS ] & NET::DesktopNames )
+            saveDesktopSettings();
+        if( dirty[ NETRootInfo::PROTOCOLS2 ] & NET::WM2DesktopLayout )
+            updateDesktopLayout();
         }
 
     // events that should be handled before Clients can get them
@@ -491,20 +495,6 @@ Window Workspace::findSpecialEventWindow( XEvent* e )
         };
     }
 
-/*!
-  Handles client messages sent to the workspace
- */
-bool Workspace::netCheck( XEvent* e )
-    {
-    unsigned int dirty = rootInfo->event( e );
-
-    if ( dirty & NET::DesktopNames )
-        saveDesktopSettings();
-
-    return dirty != 0;
-    }
-
-
 // ****************************************
 // Client
 // ****************************************
@@ -592,6 +582,7 @@ bool Client::windowEvent( XEvent* e )
         case MotionNotify:
             motionNotifyEvent( e->xmotion.window, e->xmotion.state,
                 e->xmotion.x, e->xmotion.y, e->xmotion.x_root, e->xmotion.y_root );
+            workspace()->updateFocusMousePosition( QPoint( e->xmotion.x_root, e->xmotion.y_root ));
             break;
         case EnterNotify:
             enterNotifyEvent( &e->xcrossing );
@@ -602,11 +593,14 @@ bool Client::windowEvent( XEvent* e )
             // events simpler (Qt does that too).
             motionNotifyEvent( e->xcrossing.window, e->xcrossing.state,
                 e->xcrossing.x, e->xcrossing.y, e->xcrossing.x_root, e->xcrossing.y_root );
+            workspace()->updateFocusMousePosition( QPoint( e->xcrossing.x_root, e->xcrossing.y_root ));
             break;
         case LeaveNotify:
             motionNotifyEvent( e->xcrossing.window, e->xcrossing.state,
                 e->xcrossing.x, e->xcrossing.y, e->xcrossing.x_root, e->xcrossing.y_root );
             leaveNotifyEvent( &e->xcrossing );
+            // not here, it'd break following enter notify handling
+            // workspace()->updateFocusMousePosition( QPoint( e->xcrossing.x_root, e->xcrossing.y_root ));
             break;
         case FocusIn:
             focusInEvent( &e->xfocus );
@@ -902,13 +896,19 @@ void Client::enterNotifyEvent( XCrossingEvent* e )
             autoRaiseTimer->start( options->autoRaiseInterval, TRUE  );
             }
 
-        if ( options->focusPolicy !=  Options::FocusStrictlyUnderMouse && ( isDesktop() || isDock() || isTopMenu() ) )
+        QPoint currentPos( e->x_root, e->y_root );
+        if ( options->focusPolicy != Options::FocusStrictlyUnderMouse && ( isDesktop() || isDock() || isTopMenu() ) )
             return;
-        if ( options->delayFocus )
-            workspace()->requestDelayFocus( this );
-        else
-            workspace()->requestFocus( this );
-
+        // for FocusFollowsMouse, change focus only if the mouse has actually been moved, not if the focus
+        // change came because of window changes (e.g. closing a window) - #92290
+        if( options->focusPolicy != Options::FocusFollowsMouse
+            || currentPos != workspace()->focusMousePosition())
+            {
+            if ( options->delayFocus )
+                workspace()->requestDelayFocus( this );
+            else
+                workspace()->requestFocus( this );
+            }
         return;
         }
     }
@@ -1002,8 +1002,22 @@ void Client::ungrabButton( int modifier )
  */
 void Client::updateMouseGrab()
     {
+    if( workspace()->globalShortcutsDisabled())
+        {
+        XUngrabButton( qt_xdisplay(), AnyButton, AnyModifier, wrapperId());
+        // keep grab for the simple click without modifiers if needed (see below)
+        bool not_obscured = workspace()->topClientOnDesktop( workspace()->currentDesktop(), true, false ) == this;
+        if( !( !options->clickRaise || not_obscured ))
+            grabButton( None );
+        return;
+        }
     if( isActive() && !workspace()->forcedGlobalMouseGrab()) // see Workspace::establishTabBoxGrab()
         {
+        // first grab all modifier combinations
+        XGrabButton(qt_xdisplay(), AnyButton, AnyModifier, wrapperId(), FALSE,
+            ButtonPressMask,
+            GrabModeSync, GrabModeAsync,
+            None, None );
         // remove the grab for no modifiers only if the window
         // is unobscured or if the user doesn't want click raise
         // (it is unobscured if it the topmost in the unconstrained stacking order, i.e. it is
