@@ -1,5 +1,6 @@
 /* This file is part of the KDE project
    Copyright (C) 1998-2000 David Faure <faure@kde.org>
+                 2003      Sven Leiber <s.leiber@web.de>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -12,8 +13,8 @@
 
    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.
 */
 
 #ifndef __knewmenu_h
@@ -25,13 +26,14 @@
 #include <kaction.h>
 #include <kdialogbase.h>
 #include <kurl.h>
+#include <libkonq_export.h>
 
 namespace KIO { class Job; }
 
 class KDirWatch;
 class KLineEdit;
 class KURLRequester;
-
+class QPopupMenu;
 
 /**
  * The 'New' submenu, both for the File menu and the RMB popup menu.
@@ -47,10 +49,11 @@ class KURLRequester;
  * Ideas and code for the new template handling mechanism ('link' desktop files)
  * from Christoph Pickart <pickart@iam.uni-bonn.de>
  */
-class KNewMenu : public KActionMenu
+class LIBKONQ_EXPORT KNewMenu : public KActionMenu
 {
   Q_OBJECT
 public:
+
     /**
      * Constructor
      */
@@ -78,6 +81,11 @@ public slots:
     void slotCheckUpToDate( );
 
 protected slots:
+    /**
+     * Called when New->Directory... is clicked
+     */
+    void slotNewDir();
+
     /**
      * Called when New->* is clicked
      */
@@ -105,6 +113,11 @@ private:
      */
     void parseFiles();
 
+    /**
+     * Make the main menus on the startup.
+     */
+    void makeMenus();
+
     /**
      * For entryType
      * LINKTOTEMPLATE: a desktop file that points to a file or dir to copy
@@ -192,7 +205,7 @@ protected slots:
     void slotURLTextChanged( const QString& );
 private:
     void initDialog( const QString& textFileName, const QString& defaultName, const QString& textUrl, const QString& defaultUrl );
-private:
+
     /**
      * The line edit widget for the fileName
      */
