@@ -46,6 +46,7 @@
 
 
 #define XP_UNIX
+#define MOZ_X11
 #include "sdk/npupp.h"
 
 typedef char* NP_GetMIMEDescriptionUPP(void);
@@ -85,6 +86,7 @@ protected:
   bool create( const QString& url, const QString& mimeType, void *notify, bool forceNotify = false );
   int tries() { return _tries; }
   void inform( );
+  void updateURL( const KURL& newURL );
 
   class NSPluginInstance *_instance;
   uint16 _streamType;
@@ -126,6 +128,7 @@ protected slots:
   void totalSize(KIO::Job *job, KIO::filesize_t size);
   void mimetype(KIO::Job * job, const QString &mimeType);
   void result(KIO::Job *job);
+  void redirection(KIO::Job *job, const KURL& url);
   void resume();
 
 protected:
@@ -218,7 +221,6 @@ private:
 
   bool _destroyed;
   bool _visible;
-  bool _firstResize;
   void addTempFile(KTempFile *tmpFile);
   QPtrList<KTempFile> _tempFiles;
   NSPluginCallbackIface_stub *_callback;
